==> zygrib_3.5.0.orig.tar.gz: zygrib-3.5.0/src/FileLoaderIAC.h <==
/**********************************************************************
zyGrib: meteorological GRIB file viewer
Copyright (C) 2008 - Jacques Zaninetti - http://www.zygrib.org

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
***********************************************************************/

/*************************

Download GRIB File on zygrib.org


*************************/

#ifndef FILELOADER_IAC_H
#define FILELOADER_IAC_H

#include <QObject>
#include <QtNetwork>
#include <QBuffer>
        

class FileLoaderIAC : public QObject
{ Q_OBJECT
    public:
		enum FileModeIAC
			{
				ANALYSE_FILE,
			  	FORECAST_FILE
			};
    
        FileLoaderIAC();
        ~FileLoaderIAC();
        
        void getFile(FileModeIAC IACmode);
        void stop();
        
    private:
        QHttp   *http;
        QString host;
        QByteArray arrayContent;
        
        int     idFileIAC;    // id des requêtes
        bool	fileLoaded;
        
        QString fileName;
        
        int     step;
        int     fileSize;

        QString zygriblog;
        QString zygribpwd;

        QBuffer    ioBuffer;

    public slots:
        void requestFinished (int id, bool error);
        void dataReadProgress (int done, int total );
        void slotDone (bool error);

    signals:
        void signalIACdataReceived(QByteArray *content, QString);
        void signalIACreadProgress(int step, int done, int total);
        void signalIACsendMessage(QString msg);
        void signalIACstartLoadData();
        void signalIACloadError(QString msg);
};


#endif

==> zygrib_3.9.2.orig.tar.gz: zygrib-3.9.2/src/FileLoaderIAC.h <==
/**********************************************************************
zyGrib: meteorological GRIB file viewer
Copyright (C) 2008-2010 - Jacques Zaninetti - http://www.zygrib.org

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
***********************************************************************/

/*************************

Download IAC File on zygrib.org

*************************/

#ifndef FILELOADER_IAC_H
#define FILELOADER_IAC_H

#include <QObject>
#include <QtNetwork>
#include <QBuffer>
        
#include "FileLoader.h"

class FileLoaderIAC : public QObject, FileLoader
{ Q_OBJECT
    public:
		enum FileModeIAC
			{
				ANALYSE_FILE,
			  	FORECAST_FILE
			};
    
        FileLoaderIAC();
        ~FileLoaderIAC();
        
        void getFile(FileModeIAC IACmode);
        void stop();
        
    private:
        QHttp   *http;
        QString host;
        QByteArray arrayContent;
        
        int     idFileIAC;    // id des requêtes
        bool	fileLoaded;
        
        QString fileName;
        
        int     step;
        int     fileSize;

        QString zygriblog;
        QString zygribpwd;

        QBuffer    ioBuffer;

    public slots:
        void requestFinished (int id, bool error);
        void dataReadProgress (int done, int total );
        void slotDone (bool error);

    signals:
        void signalIACdataReceived(QByteArray *content, QString);
        void signalIACreadProgress(int step, int done, int total);
        void signalIACsendMessage(QString msg);
        void signalIACstartLoadData();
        void signalIACloadError(QString msg);
};


#endif
